RemoteShard

Struct RemoteShard 

pub struct RemoteShard { /* private fields */ }
Handle to a specific target shard for message sending.

Implementations

Source

impl RemoteShard

pub fn id(&self) -> ShardId

Returns the destination shard id.

pub fn send_raw(&self, tag: u16, val: u32) -> Result<SendTicket, SendError>

Sends one raw (tag, val) message and returns an acknowledgement ticket.

pub fn send_raw_nowait(&self, tag: u16, val: u32) -> Result<(), SendError>

Sends one raw (tag, val) message without waiting for acknowledgement.

pub fn send_many_raw_nowait<I>(&self, msgs: I) -> Result<(), SendError>
where I: IntoIterator<Item = (u16, u32)>,

Sends a batch of raw messages without acknowledgement tickets.

pub fn send_raw_direct_nowait( &self, tag: u16, val: u32, ) -> Result<(), SendError>

Attempts direct in-ring submission for one message when called on-shard.

Falls back to queued path when called outside runtime worker context.

pub fn send_many_raw_direct_nowait<I>(&self, msgs: I) -> Result<(), SendError>
where I: IntoIterator<Item = (u16, u32)>,

Attempts direct in-ring submission for a batch when called on-shard.

Falls back to queued path when called outside runtime worker context.

pub fn send<M: RingMsg>(&self, msg: M) -> Result<SendTicket, SendError>

Sends a typed message and returns an acknowledgement ticket.

pub fn send_nowait<M: RingMsg>(&self, msg: M) -> Result<(), SendError>

Sends a typed message without waiting for acknowledgement.

pub fn send_many_nowait<M, I>(&self, msgs: I) -> Result<(), SendError>
where M: RingMsg, I: IntoIterator<Item = M>,

Sends a batch of typed messages without acknowledgement.

pub fn flush(&self) -> Result<SendTicket, SendError>

Flushes pending local sends and returns a completion ticket.